package edu.berkeley.cs.cs162;

/**
   An Observer is a thread that can observe games. Observers may watch any
   number of games they wish and will be notified of all game events, but can
   choose to respond to these events in whatever way they want.
*/
public abstract class Observer implements Runnable {
    String name;

    /* Sets this observer's name. */
    public void setName(String name) { this.name = name; }
    
    /* Returns the name of this observer. */
    public String getName() { return name; }

    /* Handler methods for all game events */
    public abstract void handleGameStart(String gameName, String blackPlayerName, String whitePlayerName, Board board, int moveTimeoutInMs);
    public abstract void handleGameOver(String gameName, double blackPlayerScore, double whitePlayerScore);
    public abstract void handleMakeMove(String gameName, String playerName);    
    public abstract void handleStonePlaced(String gameName, String playerName, Location loc, StoneColor color);
    public abstract void handleStoneCaptured(String gameName, String playerName, Location loc, StoneColor color);
    public abstract void handlePlayerPass(String gameName, String playerName);
    public abstract void handlePlayerError(String gameName, String playerName, String errorDescription);

    /* beginExit() is called to inform a running observer that it should 
terminate */
    public abstract void beginExit();

    public abstract void run();
}


